==> haskell-lsp-types1.4-1.4.0.1-148-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.4.0.1
visibility:           public
id:                   lsp-types-1.4.0.1-B685s83r1J2J9QgDKqnOat
key:                  lsp-types-1.4.0.1-B685s83r1J2J9QgDKqnOat
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  ef0421e2ee4fedad4bcea3936f47c1e0
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap
    Language.LSP.VFS

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types1.4
hs-libraries:         HSlsp-types-1.4.0.1-B685s83r1J2J9QgDKqnOat
depends:
    Diff-0.4.1-LlG9CqI0BWmDdGO3rVr0iN
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb filepath-1.4.2.2
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    hslogger-1.3.1.2-HizOYagnRFdDuoLuue81te
    lens-5.2.3-FHiEVacHNvQGoO0ETRbZ1i
    mod-0.2.0.1-B0WDc4GgRLuAHc6ujRVfDN mtl-2.2.2
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG
    rope-utf16-splay-0.4.0.0-I4cp0XfbPQMAa72Q14wz6j
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK
    some-1.0.6-3jwijwQA4Ou8FJ8XRvJrOP template-haskell-2.19.0.0
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN text-2.0.2
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i

haddock-interfaces:   /usr/share/doc/haskell-lsp-types1.4/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types1.4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp-types1.4-1.4.0.1-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp-types1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp-types
version:              1.4.0.1
visibility:           public
id:                   lsp-types-1.4.0.1-AY3ohLqxS7T53Hbbeuxmhx
key:                  lsp-types-1.4.0.1-AY3ohLqxS7T53Hbbeuxmhx
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:
    Haskell library for the Microsoft Language Server Protocol, data types

description:
    An implementation of the types to allow language implementors to
    support the Language Server Protocol for their specific language.

category:             Development
abi:                  2c026e40e74873bce50ef6b132caa666
exposed:              True
exposed-modules:
    Data.IxMap Language.LSP.Types Language.LSP.Types.Capabilities
    Language.LSP.Types.Lens Language.LSP.Types.SMethodMap
    Language.LSP.VFS

hidden-modules:
    Language.LSP.Types.CallHierarchy Language.LSP.Types.Cancellation
    Language.LSP.Types.ClientCapabilities Language.LSP.Types.CodeAction
    Language.LSP.Types.CodeLens Language.LSP.Types.Command
    Language.LSP.Types.Common Language.LSP.Types.Completion
    Language.LSP.Types.Configuration Language.LSP.Types.Declaration
    Language.LSP.Types.Definition Language.LSP.Types.Diagnostic
    Language.LSP.Types.DocumentColor Language.LSP.Types.DocumentFilter
    Language.LSP.Types.DocumentHighlight
    Language.LSP.Types.DocumentLink Language.LSP.Types.DocumentSymbol
    Language.LSP.Types.FoldingRange Language.LSP.Types.Formatting
    Language.LSP.Types.Hover Language.LSP.Types.Implementation
    Language.LSP.Types.Initialize Language.LSP.Types.Location
    Language.LSP.Types.LspId Language.LSP.Types.MarkupContent
    Language.LSP.Types.Method Language.LSP.Types.Message
    Language.LSP.Types.Parsing Language.LSP.Types.Progress
    Language.LSP.Types.Registration Language.LSP.Types.References
    Language.LSP.Types.Rename Language.LSP.Types.SelectionRange
    Language.LSP.Types.ServerCapabilities
    Language.LSP.Types.SemanticTokens Language.LSP.Types.SignatureHelp
    Language.LSP.Types.StaticRegistrationOptions
    Language.LSP.Types.TextDocument Language.LSP.Types.TypeDefinition
    Language.LSP.Types.Uri Language.LSP.Types.Utils
    Language.LSP.Types.Window Language.LSP.Types.WatchedFiles
    Language.LSP.Types.WorkspaceEdit
    Language.LSP.Types.WorkspaceFolders
    Language.LSP.Types.WorkspaceSymbol

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-types-1.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp-types1.4
hs-libraries:         HSlsp-types-1.4.0.1-AY3ohLqxS7T53Hbbeuxmhx
depends:
    Diff-0.4.1-LlG9CqI0BWmDdGO3rVr0iN
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi deepseq-1.4.8.0
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb filepath-1.4.2.2
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    hslogger-1.3.1.2-HizOYagnRFdDuoLuue81te
    lens-5.2.3-Isa4dKSpN0VIExKvKDKWKp
    mod-0.2.0.1-B0WDc4GgRLuAHc6ujRVfDN mtl-2.2.2
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG
    rope-utf16-splay-0.4.0.0-I4cp0XfbPQMAa72Q14wz6j
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK
    some-1.0.6-3jwijwQA4Ou8FJ8XRvJrOP template-haskell-2.19.0.0
    temporary-1.3-8FAts4F1AmtHqh7aYyLCzN text-2.0.2
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i

haddock-interfaces:   /usr/share/doc/haskell-lsp-types1.4/html/lsp-types.haddock
haddock-html:         /usr/share/doc/haskell-lsp-types1.4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
